#!/usr/bin/env python3
import json
import os
from datetime import datetime


def generate_metadata(
    machine,
    version,
    artifacts_image,
    sdk,
    output_dir,
    outlocal_dir,
):
    """Generates a metainfo.json for the release"""

    install_script = None
    licenses = None
    image_general = None
    image_wic = None

    # Join filepath for metadata

    if output_dir is not None:
        filepath = os.path.join(output_dir, machine, "metainfo.json")
    elif outlocal_dir is not None:
        filepath = os.path.join(outlocal_dir, machine, "metainfo.json")
    else:
        print("Error: Filepath is empty")
        return -1

    # Collect metadata and write to metainfo.json

    for artifact in artifacts_image:
        if artifact == "fng-install.sh":
            install_script = artifact
        elif artifact == "license.manifest":
            licenses = artifact
        elif artifact.endswith(machine + ".tar.gz"):
            image_general = artifact
        elif artifact.endswith(machine + ".wic"):
            image_wic = artifact

    metadata = dict()

    metadata["files"] = []
    metadata["version"] = version
    metadata["machine"] = machine
    metadata["date"] = datetime.today().strftime("%Y-%m-%d")

    if install_script is not None:
        new_file = dict()
        new_file["name"] = "Install Script"
        new_file["path"] = install_script
        metadata["files"].append(new_file)

    if image_general is not None:
        new_file = dict()
        new_file["name"] = "Image"
        new_file["path"] = image_general
        metadata["files"].append(new_file)

    if image_wic is not None:
        new_file = dict()
        new_file["name"] = "SD-Card Image (WIC)"
        new_file["path"] = image_wic
        metadata["files"].append(new_file)

    if sdk is not None:
        new_file = dict()
        new_file["name"] = "SDK"
        new_file["path"] = "sdk/" + sdk + ".sh"
        metadata["files"].append(new_file)

    if licenses is not None:
        new_file = dict()
        new_file["name"] = "Licenses"
        new_file["path"] = licenses
        metadata["files"].append(new_file)

    with open(filepath, "w", encoding="utf-8") as file:
        file.write(json.dumps(metadata))
